==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-desktopswitch/translations/desktopswitch_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="85"/>
        <source>Switch to desktop %1</source>
        <translation>Schakel over naar bureaublad %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="144"/>
        <location filename="../desktopswitch.cpp" line="155"/>
        <source>Desktop %1</source>
        <translation>bureaublad %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation>Instellingen voor Bureaubladwisselaar</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Aantal rijen:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Bureaubladlabels:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Uiterlijk</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Getallen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Namen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>Indien aangevinkt is de bureaubladwisselaar alleen een indicator</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>Toon alleen in actieve desktop</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>Bureaubladnamen</translation>
    </message>
</context>
</TS>

==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-desktopswitch/translations/desktopswitch_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="85"/>
        <source>Switch to desktop %1</source>
        <translation>Ga naar werkblad %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="144"/>
        <location filename="../desktopswitch.cpp" line="155"/>
        <source>Desktop %1</source>
        <translation>Werkblad %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation>Werkbladwisselaar-instellingen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Aantal rijen:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Werkbladlabels:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Vormgeving</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Getallen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Namen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>Schakel in om de werkbladwisselaar alleen als indicator te tonen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>Alleen tonen op actief werkblad</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>Werkbladnamen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="69"/>
        <source>Desktop %1:</source>
        <translation>Werkblad %1:</translation>
    </message>
</context>
</TS>
